function I = generateImages( Iin, nImg, brk_range, brk_type, DITHER )

nImg = str2double(nImg);
if mod(nImg,2), nImg = nImg+1; end;

% If input image is gray...
for n=1:size(Iin,4)
  if size(Iin,3) == 1, Iin = repmat(Iin,[1 1 3]); end;
end

% bracketing values:
brk_range= str2double(brk_range);
f_factor = @( k )( (2/nImg*k-1)^2*(brk_range-1)+1 );
f_facALT = @( k )( abs(2/nImg*k-1)*brk_range );
f_facALT2= @( k )( abs(2/nImg*k-1) );

f_multip = @( i, k )( double( k <  nImg/2)*max( 0, f_factor(k).*(i-1)+1 ) +...
                      double( k >= nImg/2)*min( 1, f_factor(k).* i )      );
f_power  = @( i, k )( double( k <  nImg/2)*i.^(1/f_factor(k)) + ...
                      double( k >= nImg/2)*i.^(  f_factor(k)) );
f_addit  = @( i, k )( double( k <  nImg/2)*max( 0, i -.1*f_facALT(k)) +...
                      double( k >= nImg/2)*min( 1, i +.1*f_facALT(k)) );
f_addit2 = @( i, k )( double( k <  nImg/2)*max( 0, min(1, brk_range*(i-.5)+.5 +f_facALT2(k)*(1-brk_range)/2 )) +...
                      double( k >= nImg/2)*min( 1, max(0, brk_range*(i-.5)+.5 -f_facALT2(k)*(1-brk_range)/2 )) );

% Normalize input image
Iin = (Iin - min(Iin(:))) ./ (max(Iin(:)) - min(Iin(:)));
fprintf('\nOriginal image was normalized\n');

DITHER = logical(str2double(DITHER));

I = zeros([ size(Iin), nImg ]);
switch brk_type
    case 'multip'
        if DITHER
            for n = 0:nImg
                I(:,:,:,1+n) = f_multip(Iin,n) + (f_factor(n)-1)*(rand(size(Iin))-.5)/127.5;
            end
        else
            for n = 0:nImg
                I(:,:,:,1+n) = f_multip(Iin,n);
            end
        end
        % fprintf('\nMultiplicative factors used:\n');
        f = f_multip;
    case 'power'
        for n = 0:nImg
            I(:,:,:,1+n) = f_power(Iin,n);
        end
        % fprintf('\nPowers used:\n');
        f = f_power;
    case 'addit'
        for n = 0:nImg
            I(:,:,:,1+n) = f_addit(Iin,n);
        end
        % fprintf('\nOffsets used:\n');
        f = f_addit;
    case 'addit2'
        for n = 0:nImg
            I(:,:,:,1+n) = f_addit2(Iin,n);
        end
        % fprintf('\nOffsets used:\n');
        f = f_addit2;
    otherwise
        error('Incorrect bracketing type');
end

myclr_blue       = [ .15, .45,  1  ];
myclr_lightblue  = [ .20, .70,  1  ];
myclr_darkblue   = [ .10, .30, .80 ];
myclr_red        = [  1 , .20,  0  ];
myclr_green      = [ .10, .70,  0  ];
myclr_lightgreen = [ .50, .85, .10 ];
myclr_pink       = [  1 , .50, .90 ];
myclr_purple     = [ .50, .30, .70 ];
myclr_yellow     = [  1 , .90,  0  ];
myclr_orange     = [  1 , .70, .1  ];
myclr_all = cat(1,myclr_darkblue,...
                  myclr_blue,...
                  myclr_lightblue,...
                  myclr_green,...
                  myclr_lightgreen,...
                  myclr_yellow,...
                  myclr_orange,...
                  myclr_red,...
                  myclr_pink,...
                  myclr_purple);
myclr_all = cat(1,myclr_all,myclr_all);

fighandle = figure('visible','off');
x = 0:.001:1;
legtxt = cell(nImg+1,1);
for k = 0:nImg
    % fprintf('%.2f ',f_factor(k));
    legtxt{k+1} = sprintf('k=%d',k);
    plot(x, f( x, k ), 'color', myclr_all(nImg+1-k,:), 'linewidth', 1.8); hold on;
end
hold off; axis image; xlim([0 1]); ylim([0 1]);
% {'k=0','k=1','k=2','k=3','k=4','k=5','k=6','k=7','k=8','k=9','k=10','k=11','k=12'}
legend(legtxt,'FontSize',16,'Location','SouthEast');
set(gca,'position',[0 0 1 1],'units','normalized')
set(gcf,'PaperUnits','Inches','PaperPosition',[0 0 5.12 5.12])
print -dpng remappingFunctions.png -r100
end
