function runEF( Wc, Ws, We, MODE, nImg, brk_range, brk_type, SCB, blackSat, whiteSat, muE, sigE, DITHER )

if ~exist('Wc','var'), Wc='1'; warning('Parameter Wc missing (automatically set to 1)'); end;
if ~exist('Ws','var'), Ws='1'; warning('Parameter Ws missing (automatically set to 1)'); end;
if ~exist('We','var'), We='1'; warning('Parameter We missing (automatically set to 1)'); end;
if ~exist('SCB','var'), SCB = 'true'; warning('Parameter SCB missing (automatically set to true)'); end;
if ~exist('blackSat','var'), blackSat = '1'; warning('Parameter blackSat missing (automatically set to 1%)'); end;
if ~exist('whiteSat','var'), whiteSat = '1'; warning('Parameter whiteSat missing (automatically set to 1%)'); end;
if ~exist('sigE','var'), sigE = '0.2'; warning('Parameter sigE missing (automatically set to 0.2)'); end;
if ~exist('DITHER','var'), DITHER = 'false'; warning('Parameter DITHER missing (automatically set to false)'); end;

% Unzip file (if find one)
zipfile = dir('*.zip');
if ~isempty(zipfile)
    if system(['unzip "' zipfile(1).name '" && rm -f "' zipfile(1).name '"']) > 2
        error('Unable to unzip file');
    end
else
    if exist('input_0', 'file')
        % Matlab is able to find out type without extension
        try img = imread('input_0');
        catch
            % input_0 is not an image
            if system('unzip input_0 && rm -f input_0') > 2
                error('Unable to read file "input_0"');
            end
        end
        % TMP: the following is not very nice.
        if exist('img', 'var')
            system('rm -f input_0'); imwrite(img,'input_0.png');
            clear img;
        end
    end
end

% Find images in current directory and sub-directory
[file_list, nb_of_files] = findImages( struct([]), 0, '.' );

% Now, add files to sequence I, generate them if single_mode activated
fprintf('\n');

if nb_of_files == 0
    error('No input images.\nDEBUG: pwd:%s\nDEBUG: ls:%s',pwd,ls);
else
    SINGLE_MODE = ( nb_of_files == 1 );
    fprintf('Adding file %s to inputs.\n',file_list(1).name);
    img_cur = imread(file_list(1).name);
    [h_pre,w_pre,d_pre] = size(img_cur);
    % Handle size of input images
    if     d_pre < 3,     img_cur = repmat(img_cur(:,:,1),[1,1,3]);
    elseif d_pre > 3,     img_cur = img_cur(:,:,1:3);
    end
    % Handle dynamic of input images
    img_cur = double(img_cur)/double(intmax(class(img_cur)));
    I = img_cur;
end

for n = 2:nb_of_files % won't be executed if nb_of_files < 2

    fprintf('Adding file %s to inputs.\n',file_list(n).name);
    img_cur = imread(file_list(n).name);
    [h_cur,w_cur,d_cur] = size(img_cur);

    % Handle size of input images
    if     h_cur < h_pre, I = I(1:h_cur,:,:,:);
    elseif h_cur > h_pre, h_cur = h_pre;
    end
    if     w_cur < w_pre, I = I(:,1:w_cur,:,:);
    elseif w_cur > w_pre, w_cur = w_pre;
    end
    if     d_cur < 3,     img_cur = repmat(img_cur(:,:,1),[1,1,3]);
    elseif d_cur > 3,     img_cur = img_cur(:,:,1:3);
    end

    % Handle dynamic of input images
    img_cur = double(img_cur)/double(intmax(class(img_cur)));

    I = cat(4,I,img_cur(1:h_cur,1:w_cur,:));

    h_pre = h_cur;
    w_pre = w_cur;
end

if SINGLE_MODE % Generate others images
    I = generateImages( I, nImg, brk_range, brk_type, DITHER );
end

% Apply Exposure Fusion
[R,W] = exposure_fusion(I,[str2double(Wc) str2double(Ws) str2double(We)],str2double(muE),str2double(sigE));

% DEBUG
% for n=1:size(I,4)
%     Yr = I(:,:,1,n); Yg = I(:,:,2,n); Yb = I(:,:,3,n);
%     fprintf('input_%d: canal R: min=%.3f max=%.3f\n',n,min(Yr(:)),max(Yr(:)));
%     fprintf('input_%d: canal G: min=%.3f max=%.3f\n',n,min(Yg(:)),max(Yg(:)));
%     fprintf('input_%d: canal B: min=%.3f max=%.3f\n',n,min(Yb(:)),max(Yb(:)));
% end; clear Yr Yg Yb

% Print min and max in each channel of image after Exposure Fusion
fprintf('\nMeasure min and max in EF output:\n');
Rr = R(:,:,1); Rg = R(:,:,2); Rb = R(:,:,3);
fprintf('Canal R: min=%.3f max=%.3f\n',min(Rr(:)),max(Rr(:)));
fprintf('Canal G: min=%.3f max=%.3f\n',min(Rg(:)),max(Rg(:)));
fprintf('Canal B: min=%.3f max=%.3f\n',min(Rb(:)),max(Rb(:)));

if logical(str2double(SCB))
    fprintf('\n');
    R = SimplestColorBalance(R, str2double(whiteSat)/100,...
                                str2double(blackSat)/100);
end

% Save output
imwrite(uint8(255*R),'output.png');

% Save input images
for n=1:size(I,4)
    imwrite(uint8(255*I(:,:,:,n)),['input' num2str(n-1) '.png']);
    imwrite(uint8(255*W(:,:,n)),['input' num2str(n-1) '_weights.png']);
end

% "DispersionMap"
if SINGLE_MODE
    in   = uint16(255*img_cur(:))+1;
    out  = uint16(255*R(:))+1;
    dMap = zeros(256);
    for n=1:length(in), dMap(out(n),in(n))=dMap(out(n),in(n)) +1; end
    dMap = log(1+flipud(dMap)); % dMap = imresize(dMap,2);
    imwrite(uint8(255*dMap/max(dMap(:))),parula(256),'dispersionmap.png');
end
end
